@@ -79,7 +79,7 @@ class Testbed:
         # for the token accept all the RFC 3986 unreserved characters
         r"((?P<user>[a-z0-9](-?[a-z0-9])+):(?P<token>[a-zA-Z0-9._~-]+)@)?"
         # match PPA owner, following most Launchpad rules for usernames
-        r"(?P<owner>[a-z](-?[a-z0-9])+)"
+        r"(?P<owner>[a-z0-9](-?[a-z0-9])+)"
         # match PPA name, following most Launchpad rules for PPA names
         r"/(?P<name>[a-z0-9][a-zA-Z0-9.+-]*)"
         # maybe match fingerprint, discarding leading 0x if present, case insensitive
