@@ -51,6 +51,7 @@ from typing import (
     Literal,
     Optional,
     Sequence,
+    Tuple,
     Union,
 )
 
@@ -262,6 +263,7 @@ class QemuSession:
         qemu_options: Sequence[str] = (),
         ram_size: int = 1024,
         workdir: Optional[str] = None,
+        user_shared_dirs: Optional[List[Tuple[str, str, str]]] = None,
     ) -> None:
         """
         Constructor.
@@ -282,6 +284,8 @@ class QemuSession:
         ram_size: Amount of RAM in MiB
         workdir: Directory for temporary files (default: a random
             subdirectory of $TMPDIR)
+        user_shared_dirs: List of tuples (hostdir, guestdir, tag) for host
+            directories to mount in the guest using the given 9p tag
         """
 
         self.consoles = set(["hvc0", "hvc1"])
@@ -292,6 +296,7 @@ class QemuSession:
         self.qemu_command = qemu_command
         self.ram_size = ram_size
         self.ssh_port = find_free_port(10022)
+        self.user_shared_dirs = user_shared_dirs or []
 
         if workdir is None:
             workdir = tempfile.mkdtemp(prefix="autopkgtest-qemu.")
@@ -383,6 +388,16 @@ class QemuSession:
             ]
         )
 
+        for hostdir, _, tag9p in self.user_shared_dirs:
+            readonly = "off" if tag9p.startswith("rw") else "on"
+            argv.extend(
+                [
+                    "-virtfs",
+                    ("local,id=%s,path=%s,security_model=none,readonly=%s,mount_tag=%s")
+                    % (tag9p, hostdir, readonly, tag9p),
+                ]
+            )
+
         for hvc in ("hvc0", "hvc1"):
             if hvc == "hvc0" and self.qemu_architecture == "ppc64le":
                 # The first -serial argument shows up as /dev/hvc0 in
